@@ -3,4 +3,4 @@
 import smoke_test_common
 
 bin_path = smoke_test_common.build_dir() + '/examples/simple-example-c'
-smoke_test_common.run([bin_path], {})
+smoke_test_common.run([bin_path], 'layer', {})
